@@ -3,6 +3,7 @@
 use anchor_lang::prelude::borsh::maybestd::io::Write;
 use anchor_lang::prelude::*;
 use borsh::{BorshDeserialize, BorshSerialize};
+use solana_program::pubkey::Pubkey;
 
 // Needed to declare accounts.
 declare_id!("Fg6PaFpoGXkYsidMpWTK6W2BeZ7FEfcYkg476zPFsLnS");
@@ -16,6 +17,7 @@ where
     pub non_generic: AccountInfo<'info>,
     pub generic: Account<'info, T>,
     pub const_generic: Loader<'info, FooAccount<N>>,
+    pub const_generic_loader: AccountLoader<'info, FooAccount<N>>,
     pub associated: Account<'info, Associated<U>>,
 }
 
@@ -45,3 +47,8 @@ impl<const N: usize> BorshDeserialize for WrappedU8Array<N> {
         todo!()
     }
 }
+impl<const N: usize> Owner for WrappedU8Array<N> {
+    fn owner() -> Pubkey {
+        crate::ID
+    }
+}
